# euclidlib

## Table of Contents

- [Introduction](#introduction)
- [Installation](#installation)
- [Usage](#usage)
- [Contributing](#contributing)
- [License](#license)
- [Acknowledgements](#acknowledgements)

## Introduction

`euclidlib` is an unofficial python package to read official Euclid mission products from the Science Ground Segment. The ultimate goal of `euclidlib` is to provide to the Euclid community a friendly and ready-to-use library that allows to work with the science-ready Euclid products right away. The library is maintained in a best-effort basis by Euclid volunteers and contributors. See acknolwedgements below.

## Installation

As simple as:

```sh
pip install euclidlib
```

### Prerequisites

- `python>3.7`
- `fitsio`
- `numpy`

## Usage

Soon to be announced.

## Contributing

If you would like to contribute, follow the following steps:

1. Open an issue to let the `euclidlib` maintainers know about your contribution plans (new Euclid product? New feature? A suggestion?)
2. Create a new branch:
   ```sh
   git checkout -b feature/your-feature-name
   ```
3. Commit your changes:
   ```sh
   git commit -m 'Add some feature'
   ```
4. Push to the branch:
   ```sh
   git push origin feature/your-feature-name
   ```
5. Open a pull request

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.

## Acknowledgements

- Thanks to the `euclidlib` contributors so far: Will Hartley & Florian Dubath (redshift bin distribution schema), Felicitas Keil & Martin Kilbinger (photometric 2-point correlation functions reading routines), Nicolas Tessore (photometric power spectra reading routines).
